@@ -13,7 +13,7 @@ use base 'DBM::Deep::Storage';
 
 =head1 NAME
 
-DBM::Deep::Storage::File - mediate low-level interaction with storage mechanism
+DBM::Deep::Storage::File
 
 =head1 PURPOSE
 
@@ -147,7 +147,7 @@ sub size {
 
 This will set the inode value of the underlying file object.
 
-This is only needed to handle some obscure Win32 bugs. It really shouldn't be
+This is only needed to handle some obscure Win32 bugs. It reqlly shouldn't be
 needed outside this object.
 
 There is no return value.
@@ -168,17 +168,14 @@ sub set_inode {
 
 =head2 print_at( $offset, @data )
 
-This takes an offset and some data to print.
+This takes an optional offset and some data to print.
 
-C< $offset > will be used to seek into the file. If file_offset is
+C< $offset >, if defined, will be used to seek into the file. If file_offset is
 set, it will be used as the zero location. If it is undefined, no seeking will
 occur. Then, C< @data > will be printed to the current location.
 
 There is no return value.
 
-If writing to the file would make the file too big for the C<pack_size> that
-is a fatal error.
-
 =cut
 
 sub print_at {
@@ -188,16 +185,13 @@ sub print_at {
     local ($,,$\);
 
     my $fh = $self->{fh};
-    my $len = length( join '', @_ );
-
-    seek( $fh, $loc + $self->{file_offset}, SEEK_SET );
-
-    if(tell($fh) > $len + 2 ** (8 * $self->{byte_size}) - 1) {
-        die("DBM::Deep: too much data, try a bigger pack_size\n");
+    if ( defined $loc ) {
+        seek( $fh, $loc + $self->{file_offset}, SEEK_SET );
     }
 
     if ( DEBUG ) {
         my $caller = join ':', (caller)[0,2];
+        my $len = length( join '', @_ );
         warn "($caller) print_at( " . (defined $loc ? $loc : '<undef>') . ", $len )\n";
     }
 
